#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-AAqetyChUYH3715Bby74ZW
key:                  stack-2.9.3.1-AAqetyChUYH3715Bby74ZW
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  d556854fcc77a3bba759f853977a9375
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-AAqetyChUYH3715Bby74ZW
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-Jn1rGzu1G9XELC9vQ6NFDR array-0.5.6.0
    async-2.2.6-AoIAnpP1AE52EgJKBLwe0w
    attoparsec-0.14.4-AJVRZfhVOVzJGMVFtBGw8r base-4.18.2.1
    base64-bytestring-1.2.1.0-AgUw5Mt3ox69IoxxzahjBJ
    bytestring-0.11.5.3 casa-client-0.0.3-6hCKWcBHax4HF0Velhuful
    casa-types-0.0.3-KIzoNl0dm9BI4U37M3n7zH
    colour-2.3.7-JPvaadv1zrwLwmJ0kjLc5
    conduit-1.3.6.1-ZW0r2gxsao1PdW3Ct9TSq
    conduit-extra-1.3.8-7ewFWVPnCG8Lw0URYbSD7 containers-0.6.7
    crypton-1.0.4-46gy0b9mrJdGyBxVPjzKV1
    crypton-conduit-0.2.3-Jig7bQh9cvv47FvjD3aywo deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-53b454gmz0kFA1gZEklCYN
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-LKhvuN3zAtJ3KT7U6UK7hO filepath-1.4.300.1
    fsnotify-0.4.4.0-33OmXoHw1QoDrttCymGbQb
    generic-deriving-1.14.7-6zsNofLNDHZ38bo9dAv7yT
    hackage-security-0.6.3.2-6fwuLSB1RsuLE4y4GEwsXM
    hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT
    hi-file-parser-0.1.8.0-IC4ZHbtTOtB5GSAanN6hxU
    hpack-0.38.0-2kjmtI994ZF4O327HIYnNh hpc-0.6.2.0
    http-client-0.7.19-4NdB1UhXjPHpnfAoWeuwI
    http-client-tls-0.3.6.4-9nWpV5E7PWG8UoCj5iZhrt
    http-conduit-2.3.9.1-CJjQ4Pj4smCJ23yhm2qXQz
    http-download-0.2.1.0-3pi888R2zTwCJDVc5y2T22
    http-types-0.12.4-CXiZJUbLhJFHeSLHvVo6Rt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-LVlDFhOkM7WARlVXlbA7Co mtl-2.3.1
    mustache-2.4.3.1-FPdiVtU69NZ26NDgJEu3gI
    neat-interpolation-0.5.1.4-DkfYDCLTMO34QUx2aRy5hy
    network-uri-2.6.4.2-EKjXwcSJoi8IwfSCQFPAn2
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-7SnpJ8KlnMr6TDIti6V1EO
    pantry-0.8.3-EsmvepGN1smJjsP1M7JUhx
    path-0.9.6-EmgpGpo5biT8xZ6EEHmUCu
    path-io-1.8.2-4xRJ4ZRoKk2BqNreRPjRNA
    persistent-2.14.5.2-2dHCXQkAGIjAtyFFrH8PyZ
    persistent-sqlite-2.13.2.0-3uuRfsOZ37YGY7F1fp4xdR pretty-1.1.3.6
    primitive-0.9.1.0-5ZrX7WiTmxB6LlIfRXEiID process-1.6.19.0
    project-template-0.2.1.0-7M87dsC0LiR645PqwwPCHX
    random-1.2.1.3-DsZJWYr04hc2YE8pqhZcvw
    retry-0.9.3.1-GYliOAJ4zXAGEoeUJEB5gO
    rio-0.1.24.0-FjeuwO42Xv1FqlNsLaPWxL
    rio-prettyprint-0.1.8.0-2x3amho10B1i7ZNBA25ne
    split-0.2.5-47epspW4k5y1JnAPK4u1Hj stm-2.5.1.0
    streaming-commons-0.2.3.1-C73HOOe4PpB2gxqMbz9YrK
    tar-0.5.1.1-GLx6X3IfKGtIp1G74bxtKa template-haskell-2.20.0.0
    temporary-1.3-HXy7P617zDdIZTm3EWvMYL text-2.0.2
    text-metrics-0.3.3-AichsjliM4r1GUcQL96xyC
    th-reify-many-0.1.10-GaQEoZpQDZALidJzcGTYRp time-1.12.2
    tls-2.0.6-LAF6yg3fJJm6R1UFL5oTB transformers-0.6.1.0
    typed-process-0.2.13.0-5XonszuoAja4pQkGLa2SAh
    unicode-transforms-0.4.0.1-2mcVIQu0bQ18JIfeL7RlxS unix-2.8.4.0
    unix-compat-0.7.4.1-3g4IDjp0vr0De46QhKcu9n
    unliftio-0.2.25.1-8PFdViM4kSw68msSMSHlHp
    unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS
    yaml-0.11.11.2-2VdKE2QkoLl3uA5EaDUwWO
    zip-archive-0.4.3.2-C4qgeEAdMzGERQawPyDrS4
    zlib-0.7.1.0-CmAuYBoJGdLK0rYzal9pa

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

